@@ -18,6 +18,7 @@ from typing import Any, Dict, List, Type
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
+    CustomStepStatusType,
     DomainType,
     EndpointTypeType,
     HomeDirectoryTypeType,
@@ -29,19 +30,24 @@ from .type_defs import (
     CreateAccessResponseTypeDef,
     CreateServerResponseTypeDef,
     CreateUserResponseTypeDef,
+    CreateWorkflowResponseTypeDef,
     DescribeAccessResponseTypeDef,
+    DescribeExecutionResponseTypeDef,
     DescribeSecurityPolicyResponseTypeDef,
     DescribeServerResponseTypeDef,
     DescribeUserResponseTypeDef,
+    DescribeWorkflowResponseTypeDef,
     EndpointDetailsTypeDef,
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
     ImportSshPublicKeyResponseTypeDef,
     ListAccessesResponseTypeDef,
+    ListExecutionsResponseTypeDef,
     ListSecurityPoliciesResponseTypeDef,
     ListServersResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListUsersResponseTypeDef,
+    ListWorkflowsResponseTypeDef,
     PosixProfileTypeDef,
     ProtocolDetailsTypeDef,
     TagTypeDef,
@@ -49,6 +55,8 @@ from .type_defs import (
     UpdateAccessResponseTypeDef,
     UpdateServerResponseTypeDef,
     UpdateUserResponseTypeDef,
+    WorkflowDetailsTypeDef,
+    WorkflowStepTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -83,7 +91,7 @@ class Exceptions:
 
 class TransferClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
@@ -99,7 +107,7 @@ class TransferClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -120,7 +128,7 @@ class TransferClient(BaseClient):
         access to upload and download files over the enabled protocols using Amazon Web
         Services Transfer Family.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
@@ -137,13 +145,14 @@ class TransferClient(BaseClient):
         LoggingRole: str = None,
         Protocols: List[ProtocolType] = None,
         SecurityPolicyName: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: List["TagTypeDef"] = None,
+        WorkflowDetails: "WorkflowDetailsTypeDef" = None
     ) -> CreateServerResponseTypeDef:
         """
         Instantiates an auto-scaling virtual server based on the selected file transfer
         protocol in Amazon Web Services.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -165,16 +174,32 @@ class TransferClient(BaseClient):
         Creates a user and associates them with an existing file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
+    def create_workflow(
+        self,
+        *,
+        Steps: List["WorkflowStepTypeDef"],
+        Description: str = None,
+        OnExceptionSteps: List["WorkflowStepTypeDef"] = None,
+        Tags: List["TagTypeDef"] = None
+    ) -> CreateWorkflowResponseTypeDef:
+        """
+        Allows you to create a workflow with specified steps and step details the
+        workflow invokes after file transfer completes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.create_workflow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_workflow)
+        """
+
     def delete_access(self, *, ServerId: str, ExternalId: str) -> None:
         """
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
@@ -182,7 +207,7 @@ class TransferClient(BaseClient):
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
@@ -190,7 +215,7 @@ class TransferClient(BaseClient):
         """
         Deletes a user's Secure Shell (SSH) public key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
@@ -199,19 +224,38 @@ class TransferClient(BaseClient):
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
+    def delete_workflow(self, *, WorkflowId: str) -> None:
+        """
+        Deletes the specified workflow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.delete_workflow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_workflow)
+        """
+
     def describe_access(self, *, ServerId: str, ExternalId: str) -> DescribeAccessResponseTypeDef:
         """
         Describes the access that is assigned to the specific file transfer protocol-
         enabled server, as identified by its `ServerId` property and its `ExternalID` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
+    def describe_execution(
+        self, *, ExecutionId: str, WorkflowId: str
+    ) -> DescribeExecutionResponseTypeDef:
+        """
+        You can use `DescribeExecution` to check the details of the execution of the
+        specified workflow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_execution)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_execution)
+        """
+
     def describe_security_policy(
         self, *, SecurityPolicyName: str
     ) -> DescribeSecurityPolicyResponseTypeDef:
@@ -219,7 +263,7 @@ class TransferClient(BaseClient):
         Describes the security policy that is attached to your file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
@@ -228,7 +272,7 @@ class TransferClient(BaseClient):
         Describes a file transfer protocol-enabled server that you specify by passing
         the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
@@ -237,10 +281,18 @@ class TransferClient(BaseClient):
         Describes the user assigned to the specific file transfer protocol-enabled
         server, as identified by its `ServerId` property.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
+    def describe_workflow(self, *, WorkflowId: str) -> DescribeWorkflowResponseTypeDef:
+        """
+        Describes the specified workflow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.describe_workflow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_workflow)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -251,7 +303,7 @@ class TransferClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
@@ -263,7 +315,7 @@ class TransferClient(BaseClient):
         `UserName` value assigned to the specific file transfer protocol-enabled server,
         identified by `ServerId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
@@ -273,10 +325,20 @@ class TransferClient(BaseClient):
         """
         Lists the details for all the accesses you have on your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
+    def list_executions(
+        self, *, WorkflowId: str, MaxResults: int = None, NextToken: str = None
+    ) -> ListExecutionsResponseTypeDef:
+        """
+        Lists all executions for the specified workflow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_executions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_executions)
+        """
+
     def list_security_policies(
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListSecurityPoliciesResponseTypeDef:
@@ -284,7 +346,7 @@ class TransferClient(BaseClient):
         Lists the security policies that are attached to your file transfer protocol-
         enabled servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
@@ -295,7 +357,7 @@ class TransferClient(BaseClient):
         Lists the file transfer protocol-enabled servers that are associated with your
         Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
@@ -306,7 +368,7 @@ class TransferClient(BaseClient):
         Lists all of the tags associated with the Amazon Resource Name (ARN) that you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
@@ -317,16 +379,36 @@ class TransferClient(BaseClient):
         Lists the users for a file transfer protocol-enabled server that you specify by
         passing the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
+    def list_workflows(
+        self, *, MaxResults: int = None, NextToken: str = None
+    ) -> ListWorkflowsResponseTypeDef:
+        """
+        Lists all of your workflows.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.list_workflows)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_workflows)
+        """
+
+    def send_workflow_step_state(
+        self, *, WorkflowId: str, ExecutionId: str, Token: str, Status: CustomStepStatusType
+    ) -> Dict[str, Any]:
+        """
+        Sends a callback for asynchronous custom steps.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.send_workflow_step_state)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#send_workflow_step_state)
+        """
+
     def start_server(self, *, ServerId: str) -> None:
         """
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
@@ -335,7 +417,7 @@ class TransferClient(BaseClient):
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
@@ -344,7 +426,7 @@ class TransferClient(BaseClient):
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -362,7 +444,7 @@ class TransferClient(BaseClient):
         `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
         is set up successfully.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
@@ -371,7 +453,7 @@ class TransferClient(BaseClient):
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -391,7 +473,7 @@ class TransferClient(BaseClient):
         Allows you to update parameters for the access specified in the `ServerID` and
         `ExternalID` parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -407,13 +489,14 @@ class TransferClient(BaseClient):
         IdentityProviderDetails: "IdentityProviderDetailsTypeDef" = None,
         LoggingRole: str = None,
         Protocols: List[ProtocolType] = None,
-        SecurityPolicyName: str = None
+        SecurityPolicyName: str = None,
+        WorkflowDetails: "WorkflowDetailsTypeDef" = None
     ) -> UpdateServerResponseTypeDef:
         """
         Updates the file transfer protocol-enabled server's properties after that server
         has been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -432,12 +515,12 @@ class TransferClient(BaseClient):
         """
         Assigns new properties to a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/transfer.html#Transfer.Paginator.ListServers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/transfer.html#Transfer.Paginator.ListServers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
